# Generated by Django 2.2.28 on 2023-03-28 15:00

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('djangoldp_component', '0001_initial'),
    ]

    operations = [
        migrations.DeleteModel(
            name='Dependency',
        ),
    ]
