# Generated by Django 2.2.28 on 2023-05-19 16:04

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('djangoldp_component', '0002_delete_dependency'),
    ]

    operations = [
        migrations.AddField(
            model_name='component',
            name='auto_menu',
            field=models.BooleanField(default=False, help_text='Enable the experimental menu functionnality, require a solid-***-menu component.'),
        ),
    ]
